==> pymesh2-0.1.7.tar.gz: pymesh2-0.1.7/setup.py <==
#!/usr/bin/env python

from distutils.command.build import build
import multiprocessing
import os
import os.path
from setuptools import setup
from subprocess import check_call;

root_dir = os.path.abspath(os.path.dirname(__file__));
package_dir = os.path.join(root_dir, "python/pymesh");
exec(open(os.path.join(package_dir, 'version.py')).read())

num_cores = multiprocessing.cpu_count();
num_cores = min(1, num_cores-1);

class cmake_build(build):
    """
    Python packaging system is messed up.  This class redirect python to use
    cmake for configuration and compilation of pymesh.
    """

    def build_third_party(self):
        """
        Config and build third party dependencies.
        """
        build_dir = os.path.join(root_dir, "third_party/build");
        if not os.path.isdir(build_dir):
            os.makedirs(build_dir);

        os.chdir(build_dir);
        command = "cmake ..";
        check_call(command.split());
        command = "make clean";
        check_call(command.split());
        command = "make -j {}".format(num_cores);
        check_call(command.split());
        command = "make install";
        check_call(command.split());

    def build_pymesh(self):
        """
        Config and build pymesh.
        """
        build_dir = os.path.join(root_dir, "build");
        if not os.path.isdir(build_dir):
            os.makedirs(build_dir);

        os.chdir(build_dir);
        command = "cmake ..";
        check_call(command.split());
        command = "make clean";
        check_call(command.split());
        command = "make -j {}".format(num_cores);
        check_call(command.split());
        command = "make tools -j {}".format(num_cores);
        check_call(command.split());
        os.chdir(root_dir);

    def run(self):
        self.build_third_party();
        print("===========================");
        self.build_pymesh();
        print("===========================");
        build.run(self);
        print("+++++++++++++++++++++++++++");

setup(
        name = "pymesh2",
        description = "Mesh Processing for Python",
        version = __version__,
        author = "Qingnan Zhou",
        author_email = "qnzhou@gmail.com",
        license = "MPL",
        package_dir = {"": "python"},
        packages = ["pymesh", "pymesh.misc", "pymesh.meshutils", "pymesh.wires",
            "pymesh.tests", "pymesh.meshutils.tests", "pymesh.wires.tests"],
        package_data = {"pymesh": [
            "swig/*.py",
            "lib/*.so",
            "lib/*.dylib",
            "lib/*.dll",
            "third_party/lib/*"]},
        #include_package_data = True,
        cmdclass={'build': cmake_build},
        scripts=[
            "scripts/add_element_attribute.py",
            "scripts/add_index.py",
            "scripts/bbox.py",
            "scripts/box_gen.py",
            "scripts/boolean.py",
            "scripts/curvature.py",
            "scripts/dodecahedron_gen.py",
            "scripts/extract_self_intersecting_faces.py",
            "scripts/find_file.py",
            "scripts/fix_mesh.py",
            "scripts/geodesic.py",
            "scripts/highlight_boundary_edges.py",
            "scripts/highlight_degenerated_faces.py",
            "scripts/highlight_non_oriented_edges.py",
            "scripts/highlight_self_intersection.py",
            "scripts/highlight_zero_area_faces.py",
            "scripts/icosphere_gen.py",
            "scripts/inflate.py",
            "scripts/merge.py",
            "scripts/mesh_diff.py",
            "scripts/meshconvert.py",
            "scripts/meshstat.py",
            "scripts/microstructure_gen.py",
            "scripts/minkowski_sum.py",
            "scripts/outer_hull.py",
            "scripts/point_cloud.py",
            "scripts/print_utils.py",
            "scripts/quad_to_tri.py",
            "scripts/remove_degenerated_triangles.py",
            "scripts/resolve_self_intersection.py",
            "scripts/retriangulate.py",
            "scripts/rigid_transform.py",
            "scripts/scale_mesh.py",
            "scripts/self_union.py",
            "scripts/separate.py",
            "scripts/slice_mesh.py",
            "scripts/subdivide.py",
            "scripts/submesh.py",
            "scripts/tet.py",
            "scripts/tet_to_hex.py",
            "scripts/voxelize.py",
            ],
        url = "https://github.com/qnzhou/PyMesh",
        download_url="https://github.com/qnzhou/PyMesh/tarball/v0.1",
        );

==> pymesh2-0.1.8.tar.gz: pymesh2-0.1.8/setup.py <==
#!/usr/bin/env python

from distutils.command.build import build
import multiprocessing
import os
import os.path
from setuptools import setup
from subprocess import check_call;

root_dir = os.path.abspath(os.path.dirname(__file__));
package_dir = os.path.join(root_dir, "python/pymesh");
exec(open(os.path.join(package_dir, 'version.py')).read())

num_cores = multiprocessing.cpu_count();
num_cores = min(1, num_cores-1);

class cmake_build(build):
    """
    Python packaging system is messed up.  This class redirect python to use
    cmake for configuration and compilation of pymesh.
    """

    def build_third_party(self):
        """
        Config and build third party dependencies.
        """
        build_dir = os.path.join(root_dir, "third_party/build");
        if os.path.isdir(build_dir):
            os.removedirs(build_dir);
        os.makedirs(build_dir);

        os.chdir(build_dir);
        command = "cmake ..";
        check_call(command.split());
        command = "make -j {}".format(num_cores);
        check_call(command.split());
        command = "make install";
        check_call(command.split());

    def build_pymesh(self):
        """
        Config and build pymesh.
        """
        build_dir = os.path.join(root_dir, "build");
        if os.path.isdir(build_dir):
            os.removedirs(build_dir);
        os.makedirs(build_dir);

        os.chdir(build_dir);
        command = "cmake ..";
        check_call(command.split());
        command = "make -j {}".format(num_cores);
        check_call(command.split());
        command = "make tools -j {}".format(num_cores);
        check_call(command.split());
        os.chdir(root_dir);

    def run(self):
        self.build_third_party();
        print("===========================");
        self.build_pymesh();
        print("===========================");
        build.run(self);
        print("+++++++++++++++++++++++++++");

setup(
        name = "pymesh2",
        description = "Mesh Processing for Python",
        version = __version__,
        author = "Qingnan Zhou",
        author_email = "qnzhou@gmail.com",
        license = "MPL",
        package_dir = {"": "python"},
        packages = ["pymesh", "pymesh.misc", "pymesh.meshutils", "pymesh.wires",
            "pymesh.tests", "pymesh.meshutils.tests", "pymesh.wires.tests"],
        package_data = {"pymesh": [
            "swig/*.py",
            "lib/*.so",
            "lib/*.dylib",
            "lib/*.dll",
            "third_party/lib/*"]},
        #include_package_data = True,
        cmdclass={'build': cmake_build},
        scripts=[
            "scripts/add_element_attribute.py",
            "scripts/add_index.py",
            "scripts/bbox.py",
            "scripts/box_gen.py",
            "scripts/boolean.py",
            "scripts/curvature.py",
            "scripts/dodecahedron_gen.py",
            "scripts/extract_self_intersecting_faces.py",
            "scripts/find_file.py",
            "scripts/fix_mesh.py",
            "scripts/geodesic.py",
            "scripts/highlight_boundary_edges.py",
            "scripts/highlight_degenerated_faces.py",
            "scripts/highlight_non_oriented_edges.py",
            "scripts/highlight_self_intersection.py",
            "scripts/highlight_zero_area_faces.py",
            "scripts/icosphere_gen.py",
            "scripts/inflate.py",
            "scripts/merge.py",
            "scripts/mesh_diff.py",
            "scripts/meshconvert.py",
            "scripts/meshstat.py",
            "scripts/microstructure_gen.py",
            "scripts/minkowski_sum.py",
            "scripts/outer_hull.py",
            "scripts/point_cloud.py",
            "scripts/print_utils.py",
            "scripts/quad_to_tri.py",
            "scripts/remove_degenerated_triangles.py",
            "scripts/resolve_self_intersection.py",
            "scripts/retriangulate.py",
            "scripts/rigid_transform.py",
            "scripts/scale_mesh.py",
            "scripts/self_union.py",
            "scripts/separate.py",
            "scripts/slice_mesh.py",
            "scripts/subdivide.py",
            "scripts/submesh.py",
            "scripts/tet.py",
            "scripts/tet_to_hex.py",
            "scripts/voxelize.py",
            ],
        url = "https://github.com/qnzhou/PyMesh",
        download_url="https://github.com/qnzhou/PyMesh/tarball/v0.1",
        );
